==> peaceful-progression-1.1.0-sources.jar: xen42/peacefulitems/entities/GhastlingEntity.java <==
package xen42.peacefulitems.entities;

import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1282;
import net.minecraft.class_1296;
import net.minecraft.class_1299;
import net.minecraft.class_1303;
import net.minecraft.class_1331;
import net.minecraft.class_1347;
import net.minecraft.class_1361;
import net.minecraft.class_1374;
import net.minecraft.class_1376;
import net.minecraft.class_1391;
import net.minecraft.class_1395;
import net.minecraft.class_1407;
import net.minecraft.class_1408;
import net.minecraft.class_1429;
import net.minecraft.class_1432;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1928;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_2090;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_3414;
import net.minecraft.class_3417;
import net.minecraft.class_3730;
import net.minecraft.class_4538;
import net.minecraft.class_5132;
import net.minecraft.class_5134;
import net.minecraft.class_5819;
import net.minecraft.class_7058;
import net.minecraft.class_7924;
import xen42.peacefulitems.PeacefulMod;
import xen42.peacefulitems.PeacefulModTags;

public class GhastlingEntity extends class_1429 implements class_1432 {

    public GhastlingEntity(class_1299<? extends class_1429> entityType, class_1937 world) {
        super(entityType, world);
        this.field_6207 = new class_1331(this, 20, true);
    }

    @Override
    protected void method_5959() {
        this.field_6201.method_6277(0, new class_1347(this));
        this.field_6201.method_6277(1, new class_1374(this, 2f));
        this.field_6201.method_6277(2, new GhastlingFleeGoal(this, 16.0F, 1.4D));
        this.field_6201.method_6277(3, new class_1391(this, 1.5f, stack -> stack.method_31573(PeacefulModTags.ItemTags.WISP_LIKES), false));
        this.field_6201.method_6277(4, new class_1395(this, 1f));
        this.field_6201.method_6277(5, new class_1361(this, class_1657.class, 3f));
        this.field_6201.method_6277(6, new class_1376(this));
    }

    public static boolean isValidSpawn(class_1299<? extends GhastlingEntity> type, class_1936 world, class_3730 spawnReason, class_2338 pos, class_5819 random) {
        return world.method_8320(pos).method_26215() 
            && class_2090.class_2091.method_53183(world.method_30349().method_46762(class_7924.field_41246).method_46747(class_7058.field_37182)).method_9023()
                .method_9018((class_3218)world, pos.method_10263(), pos.method_10264(), pos.method_10260());
    }

    @Override
    public boolean method_6481(class_1799 stack) {
        return stack.method_31573(PeacefulModTags.ItemTags.WISP_LIKES);
    }

    @Override
    public float method_6144(class_2338 pos, class_4538 world) {
        return world.method_8320(pos).method_26215() ? 10.0F : world.method_42309(pos);
    }

    @Override
    public class_1296 method_5613(class_3218 world, class_1296 entity) {
        return (GhastlingEntity)PeacefulMod.GHASTLING_ENTITY.method_5883(world);
    }

    @Override
    public class_1269 method_5992(class_1657 player, class_1268 hand) {
        // Instead of breeding like normal they duplicate
        // Also handle crying
        var item = player.method_5998(hand);
        if (!method_37908().field_9236 && method_5618() == 0 && method_6482()) {
            if (method_6481(item)) {
                method_5614(6000);
                method_6475(player, hand, item);
                if (method_37908().method_8503().method_3767().method_8355(class_1928.field_19391)) {
                    method_37908().method_8649(new class_1303(method_37908(), method_23317(), method_23318(), method_23321(), method_6051().method_43048(7) + 1));
                }
                method_5783(class_3417.field_14566, 0.5f, (field_5974.method_43057() - field_5974.method_43057()) * 0.2f + 1.3f);

                var baby = PeacefulMod.GHASTLING_ENTITY.method_5883(method_37908());
                baby.method_5808(method_23317(), method_23318(), method_23321(), 0.0f, 0.0f);
                method_37908().method_8649(baby);
                baby.method_5614(6000);

                return (class_1269)class_1269.field_5812;
            }
            else if (item.method_31573(PeacefulModTags.ItemTags.WISP_DISLIKES)) {
                var tear = method_5706(class_1802.field_8070);
                tear.method_33574(method_19538());
                method_5783(class_3417.field_15130, 0.5f, (field_5974.method_43057() - field_5974.method_43057()) * 0.2f + 1.3f);
                // Treating this as breeding for the sake of having a timer and stuff
                method_5614(6000);
                method_6475(player, hand, item);
                // Count this as hurting them so they run from you
                this.method_5643(method_37908().method_48963().method_48802(player), 0f);
                return (class_1269)class_1269.field_5812;
            }
        }
        return class_1269.field_5811;
    }

    public static class_5132.class_5133 method_26828() {
        return class_1429.method_26828()
            .method_26868(class_5134.field_23720, 0.6f)
            .method_26868(class_5134.field_23719, 0.3f)
            .method_26868(class_5134.field_49077, 0f)
            .method_26868(class_5134.field_23717, 20f);
    }

    @Override
    public void method_6013(class_1282 damageSource) {
        this.method_5783(class_3417.field_15054, 1f, (field_5974.method_43057() - field_5974.method_43057()) * 0.2f + 1.3f);
    }

    @Override
    protected class_3414 method_5994() {
        return class_3417.field_14812;
    }

    @Override
    public boolean method_6581() {
        return !method_24828();
    }

    @Override
    protected void method_5623(double heightDifference, boolean onGround, class_2680 state, class_2338 landedPosition) {}

    @Override
    protected float method_6107() {
        return 0.4f;
    }

    @Override
    public boolean method_5776() {
        return method_6581();
    }

    @Override
    protected class_1408 method_5965(class_1937 world) {
        var navigation = new class_1407(this, world) {
            public boolean method_6333(class_2338 pos) {
                return !this.field_6677.method_8320(pos.method_10074()).method_26215();
            }
        };
        navigation.method_6332(true);
        navigation.method_6354(true);
        return navigation;
    }
}

==> peaceful-progression-1.1.1-sources.jar: xen42/peacefulitems/entities/GhastlingEntity.java <==
package xen42.peacefulitems.entities;

import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1282;
import net.minecraft.class_1296;
import net.minecraft.class_1299;
import net.minecraft.class_1303;
import net.minecraft.class_1331;
import net.minecraft.class_1347;
import net.minecraft.class_1361;
import net.minecraft.class_1374;
import net.minecraft.class_1376;
import net.minecraft.class_1391;
import net.minecraft.class_1395;
import net.minecraft.class_1407;
import net.minecraft.class_1408;
import net.minecraft.class_1429;
import net.minecraft.class_1432;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1928;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_2090;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_3414;
import net.minecraft.class_3417;
import net.minecraft.class_3730;
import net.minecraft.class_4538;
import net.minecraft.class_5132;
import net.minecraft.class_5134;
import net.minecraft.class_5819;
import net.minecraft.class_7058;
import net.minecraft.class_7924;
import xen42.peacefulitems.PeacefulMod;
import xen42.peacefulitems.PeacefulModTags;

public class GhastlingEntity extends class_1429 implements class_1432 {

    public GhastlingEntity(class_1299<? extends class_1429> entityType, class_1937 world) {
        super(entityType, world);
        this.field_6207 = new class_1331(this, 20, true);
    }

    @Override
    protected void method_5959() {
        this.field_6201.method_6277(0, new class_1347(this));
        this.field_6201.method_6277(1, new class_1374(this, 2f));
        this.field_6201.method_6277(2, new GhastlingFleeGoal(this, 16.0F, 1.4D));
        this.field_6201.method_6277(3, new class_1391(this, 1.5f, stack -> stack.method_31573(PeacefulModTags.ItemTags.WISP_LIKES), false));
        this.field_6201.method_6277(4, new class_1395(this, 1f));
        this.field_6201.method_6277(5, new class_1361(this, class_1657.class, 3f));
        this.field_6201.method_6277(6, new class_1376(this));
    }

    public static boolean isValidSpawn(class_1299<? extends GhastlingEntity> type, class_1936 world, class_3730 spawnReason, class_2338 pos, class_5819 random) {
        return world.method_8320(pos).method_26215() 
            && class_2090.class_2091.method_53183(world.method_30349().method_30530(class_7924.field_41246).method_46747(class_7058.field_37182)).method_9023()
                .method_9018((class_3218)world, pos.method_10263(), pos.method_10264(), pos.method_10260());
    }

    @Override
    public boolean method_6481(class_1799 stack) {
        return stack.method_31573(PeacefulModTags.ItemTags.WISP_LIKES);
    }

    @Override
    public float method_6144(class_2338 pos, class_4538 world) {
        return world.method_8320(pos).method_26215() ? 10.0F : world.method_42309(pos);
    }

    @Override
    public class_1296 method_5613(class_3218 world, class_1296 entity) {
        return (GhastlingEntity)PeacefulMod.GHASTLING_ENTITY.method_5883(world, class_3730.field_16466);
    }

    @Override
    public class_1269 method_5992(class_1657 player, class_1268 hand) {
        // Instead of breeding like normal they duplicate
        // Also handle crying
        var item = player.method_5998(hand);
        if (!method_73183().method_8608() && method_5618() == 0 && method_6482()) {
            if (method_6481(item)) {
                method_5614(6000);
                method_6475(player, hand, item);
                method_61458();
                if (method_73183().method_8503().method_3767().method_8355(class_1928.field_19391)) {
                    method_73183().method_8649(new class_1303(method_73183(), method_23317(), method_23318(), method_23321(), method_59922().method_43048(7) + 1));
                }
                method_5783(class_3417.field_14566, 0.5f, (field_5974.method_43057() - field_5974.method_43057()) * 0.2f + 1.3f);

                var baby = PeacefulMod.GHASTLING_ENTITY.method_5883(method_73183(), class_3730.field_16466);
                baby.method_5808(method_23317(), method_23318(), method_23321(), 0.0f, 0.0f);
                method_73183().method_8649(baby);
                baby.method_5614(6000);

                return (class_1269)class_1269.field_52422;
            }
            else if (item.method_31573(PeacefulModTags.ItemTags.WISP_DISLIKES)) {
                var tear = method_5706((class_3218)method_73183(), class_1802.field_8070);
                tear.method_33574(method_73189());
                method_5783(class_3417.field_15130, 0.5f, (field_5974.method_43057() - field_5974.method_43057()) * 0.2f + 1.3f);
                // Treating this as breeding for the sake of having a timer and stuff
                method_5614(6000);
                method_6475(player, hand, item);
                method_61458();
                // Count this as hurting them so they run from you
                this.method_64397((class_3218)method_73183(), method_73183().method_48963().method_48802(player), 0f);
                return (class_1269)class_1269.field_52422;
            }
        }
        return class_1269.field_5811;
    }

    public static class_5132.class_5133 method_26828() {
        return class_1429.method_61457()
            .method_26868(class_5134.field_23716, 10)
            .method_26868(class_5134.field_23720, 0.6f)
            .method_26868(class_5134.field_23719, 0.3f)
            .method_26868(class_5134.field_49077, 0f)
            .method_26868(class_5134.field_52450, 20f);
    }

    @Override
    public void method_6013(class_1282 damageSource) {
        this.method_5783(class_3417.field_15054, 1f, (field_5974.method_43057() - field_5974.method_43057()) * 0.2f + 1.3f);
    }

    @Override
    protected class_3414 method_5994() {
        return class_3417.field_14812;
    }

    @Override
    public boolean method_6581() {
        return !method_24828();
    }

    @Override
    protected void method_5623(double heightDifference, boolean onGround, class_2680 state, class_2338 landedPosition) {}

    @Override
    protected float method_6107() {
        return 0.4f;
    }

    @Override
    public boolean method_5776() {
        return method_6581();
    }

    @Override
    protected class_1408 method_5965(class_1937 world) {
        var navigation = new class_1407(this, world) {
            public boolean method_6333(class_2338 pos) {
                return !this.field_6677.method_8320(pos.method_10074()).method_26215();
            }
        };
        navigation.method_70687(true);
        navigation.method_6354(true);
        navigation.method_61439(48f);
        return navigation;
    }
}
